==> aloe-1.4.tar.gz: aloe-1.4/modules/wimax_ENCODLDPC/src/my_prog.c <==
/** Sample ALOE component implementation file
    Specific module code
*/

/** Include general data type library */
#include "typetools.h"
#include "itf_types.h"
#include "eLDPC_code.h"

/*GLOBAL VARIABLES & BUFFERS*/
//int value;
#define BSIZE	100*1024

void init_my_prog()
{
    printf("INIT_eLDPC: /home/antoni/DADES/WORK/LDPC/repository/data/802_16e.pchk");
    //Path to codification files
    pchk_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.pchk";
    gen_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.gen";
    //pchk_file = "../../../example-repository/data/802_16e.pchk";
    //gen_file = "../../../example-repository/data/802_16e.gen";
    Init_eLDPC();
    printf(" OK\n"); 
}


/** Module function generic format
 *  Returns the output length or -1 if error
 */
int my_prog(void *pdatain, void *pdataout,\
            int processingtypeIN, int processingtypeOUT,\
            int inputlength, ControlMODULENAME_h myctrl)
{

    int i, outputlength;
    float *input_f, *output_f;
    char *input_c, *output_c;
    int *input_i, *output_i;
    short *input_s, *output_s;

    int input[BSIZE], output[BSIZE];

    /**Properly typecast your input data pointer and check the input data type*/
    if(processingtypeIN==TYPE_BIT8)input_c=(char *)pdatain;
    else {
        printf("wimax_ENCODLDPC.my_prog(): ERROR INPUT DATA TYPE NON VALID\n");
        return(-1);
     }
    if(processingtypeOUT==TYPE_BIT8)output_c=(char *)pdataout;
    else {
        printf("wimax_ENCODLDPC.my_prog(): ERROR OUTPUT DATA TYPE NON VALID\n");
        return(-1);
    }

    //*YOUR CODE*/

    outputlength=inputlength*myctrl.coderate;

    for(i=0; i<inputlength; i++){
        input[i]=(int)input_c[i];
    }

    //N=2304;
    Run_EncodeeLDPC (input, output);
    

    for(i=0; i<outputlength; i++)output_c[i]=(char)output[i];
    
 
    return(outputlength);
}

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/wimax_ENCODLDPC/src/my_prog.c <==
/** Sample ALOE component implementation file
    Specific module code
*/

/** Include general data type library */
#include "typetools.h"
#include "itf_types.h"
#include "eLDPC_code.h"

/*GLOBAL VARIABLES & BUFFERS*/
//int value;
#define BSIZE	100*1024

void init_my_prog()
{
    printf("INIT_eLDPC: data/802_16e.pchk");
    //Path to codification files
    //pchk_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.pchk";
    //gen_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.gen";
    pchk_file = "data/802_16e.pchk";
    gen_file = "data/802_16e.gen";
    Init_eLDPC();
    printf(" OK\n"); 
}


/** Module function generic format
 *  Returns the output length or -1 if error
 */
int my_prog(void *pdatain, void *pdataout,\
            int processingtypeIN, int processingtypeOUT,\
            int inputlength, ControlMODULENAME_h myctrl)
{

    int i, outputlength;
    float *input_f, *output_f;
    char *input_c, *output_c;
    int *input_i, *output_i;
    short *input_s, *output_s;

    int input[BSIZE], output[BSIZE];

    /**Properly typecast your input data pointer and check the input data type*/
    if(processingtypeIN==TYPE_BIT8)input_c=(char *)pdatain;
    else {
        printf("wimax_ENCODLDPC.my_prog(): ERROR INPUT DATA TYPE NON VALID\n");
        return(-1);
     }
    if(processingtypeOUT==TYPE_BIT8)output_c=(char *)pdataout;
    else {
        printf("wimax_ENCODLDPC.my_prog(): ERROR OUTPUT DATA TYPE NON VALID\n");
        return(-1);
    }

    //*YOUR CODE*/

    outputlength=inputlength*myctrl.coderate;

    for(i=0; i<inputlength; i++){
        input[i]=(int)input_c[i];
    }

    //N=2304;
    Run_EncodeeLDPC (input, output);
    

    for(i=0; i<outputlength; i++)output_c[i]=(char)output[i];
    
 
    return(outputlength);
}
